aboutsummaryrefslogtreecommitdiff
path: root/packages/taler-wallet-core/src/versions.ts
diff options
context:
space:
mode:
Diffstat (limited to 'packages/taler-wallet-core/src/versions.ts')
-rw-r--r--packages/taler-wallet-core/src/versions.ts14
1 files changed, 7 insertions, 7 deletions
diff --git a/packages/taler-wallet-core/src/versions.ts b/packages/taler-wallet-core/src/versions.ts
index 8e0e5561b..ba6fdfaaa 100644
--- a/packages/taler-wallet-core/src/versions.ts
+++ b/packages/taler-wallet-core/src/versions.ts
@@ -36,21 +36,21 @@ export const WALLET_MERCHANT_PROTOCOL_VERSION = "5:0:1";
export const WALLET_BANK_INTEGRATION_PROTOCOL_VERSION = "0:0:0";
/**
* Semver of the wallet-core implementation.
* Will be replaced with the value from package.json in a
* post-compilation step (inside lib/).
*/
-export const WALLET_CORE_IMPLEMENTATION_VERSION = "1:0:0";
+export const WALLET_CORE_API_IMPLEMENTATION_VERSION = "2:0:1";
/**
* Libtool rules:
- *
- * If the library source code has changed at all since the last update,
+ *
+ * If the library source code has changed at all since the last update,
* then increment revision (‘c:r:a’ becomes ‘c:r+1:a’).
* If any interfaces have been added, removed, or changed since the last
* update, increment current, and set revision to 0.
- * If any interfaces have been added since the last public release, then
+ * If any interfaces have been added since the last public release, then
* increment age.
- * If any interfaces have been removed or changed since the last public
+ * If any interfaces have been removed or changed since the last public
* release, then set age to 0.
- */ \ No newline at end of file
+ */
@@ -36,21 +36,21 @@ export const WALLET_MERCHANT_PROTOCOL_VERSION = "5:0:1";
export const WALLET_BANK_INTEGRATION_PROTOCOL_VERSION = "0:0:0";
/**
- * Semver of the wallet-core implementation.
+ * Semver of the wallet-core API implementation.
* Will be replaced with the value from package.json in a
* post-compilation step (inside lib/).